@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: log.h,v $
- * $Revision: 1.16 $
- * $Date: 2011/12/28 03:22:21 $
+ * $Revision: 1.17 $
+ * $Date: 2013/09/19 01:30:56 $
  */
 
 #define SYSLOG_IDENT "samma"
@@ -37,6 +37,21 @@
 #define ERR_TEMPLATE_RELOADING		"%s: Cannot reload template(%s): (still refered)"
 #define TEMPLATE_RELOADING		"%s: reload template(%s)"
 
+
+/* ADD(20150316)*/
+#define ERR_WHITELIST_RELOADING		"%s: Cannot reload whitelist(%s): (still refered)"
+#define ERR_WHITELIST_INVALID_IP	"%s: IP address (%s) is invalid."
+#define ERR_WHITELIST_IP_INVALID	"%s: IP address (%s) is invalid (Line: %d)"
+#define ERR_WHITELIST_MASK_NOT_NUM	"%s: Netmask(%s) is not number (Line: %d)"
+#define ERR_WHITELIST_MASK_RANGEV4      "%s: Netmask(%d) from 1 to 32 (Line: %d)"
+#define ERR_WHITELIST_MASK_RANGEV6      "%s: Netmask(%d) from 1 to 128 (Line: %d)"
+
+#define WHITELIST_RELOADING		        "%s: reload whitelist(%s)"
+#define WHITELIST_NOT_ENCRYPTION            "%s: Skip encrypt file at ip address(%s)"
+
+
+
+
 #define ERR_CONFIG_FILE_OPEN	"%s: Cannot open config file.(%s): (%s)"
 #define ERR_CONFIG_LINE_LONG	"%s: %s (line: %d) is too long."
 #define ERR_CONFIG_DUPLICATED	"%s: %s (line: %d) is duplicated. (%s)"
@@ -107,6 +122,7 @@
 
 #define ERR_PASS_MUST_BE_SET	"%s: Password must be set."
 
+#define ERR_INVALID_COMMAND     "%s: Cannot analysis command.(variable=%s): (value=%d)"
 #define ERR_DELETE_ADDRESS	"%s: Cannot delete rcpt address.(%s)"
 #define ERR_SET_ENV		"%s: Cannot set environment variable.(%s)"
 #define ERR_GET_PRIV		"%s: Cannot get private data pointer."
