@@ -318,37 +318,58 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
     int index, i;
     const char *filename;
 
+
     pthread_mutex_lock(&gmime_lock);
     object = g_mime_message_get_mime_part(mz->message);
 
     if (GMIME_IS_MULTIPART (object)) {
 
+#ifndef GMIME26
         index = g_mime_multipart_get_number((GMimeMultipart *)object);
+#else
+        index = g_mime_multipart_get_count((GMimeMultipart *)object);
+#endif
 
         for (i = index - 1; i > 0; i--) {
             att = g_mime_multipart_get_part((GMimeMultipart *)object, i);
+
 	    if (GMIME_IS_MULTIPART (att)) {
+#ifndef GMIME24
                 g_object_unref (att);
+#endif
                 att = NULL;
                 continue;
 	    }
 
             filename = g_mime_part_get_filename((GMimePart *)att);
+
             if (filename == NULL) {
+#ifndef GMIME24
                 g_object_unref (att);
+#endif
                 att = NULL;
                 continue;
             }
 
+#ifndef GMIME26
             g_mime_multipart_remove_part((GMimeMultipart *)object, att);
+#else
+            g_mime_multipart_remove((GMimeMultipart *)object, att);
+#endif
+
+#ifndef GMIME24
             g_object_unref (att);
+#endif
         }
     }
 
     fp = fopen(mz->encfilepath, "r");
+
     if (fp == NULL) {
 	log(ERR_FILE_OPEN, "add_attach_file", mz->encfilepath);
+#ifndef GMIME24
         g_object_unref (object);
+#endif
         pthread_mutex_unlock(&gmime_lock);
 	return -1;
     }
@@ -357,35 +378,64 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
     part = g_mime_part_new();
 
     /* set part object */
+#ifndef GMIME26
     g_mime_part_set_content_header(part, CONTENTTYPE_HEADER, CONTENTTYPE_ZIP);
+#else
+    g_mime_object_set_header((GMimeObject *)part, CONTENTTYPE_HEADER, CONTENTTYPE_ZIP);
+#endif
+
     g_mime_part_set_filename(part, mz->attachfilename);
+
+#ifndef GMIME26
     g_mime_part_set_encoding(part, GMIME_PART_ENCODING_BASE64);
     g_mime_part_set_content_disposition(part, CONTENTDISPOSITION);
+#else
+    g_mime_part_set_content_encoding(part, GMIME_CONTENT_ENCODING_BASE64);
+    g_mime_object_set_disposition((GMimeObject *)part, CONTENTDISPOSITION);
+#endif
 
     /* open stream */
     r_stream = g_mime_stream_file_new(fp); 
 
     /* create filter object */
+#ifndef GMIME26
     filter = g_mime_filter_basic_new_type(GMIME_FILTER_BASIC_BASE64_ENC);
+#else
+    filter = g_mime_filter_basic_new(GMIME_CONTENT_ENCODING_BASE64, TRUE);
+#endif
 
     /* set filter */
+#ifndef GMIME26
     f_stream = g_mime_stream_filter_new_with_stream(r_stream);
+#else
+    f_stream = g_mime_stream_filter_new(r_stream);
+#endif
+
     g_object_unref (r_stream);
     g_mime_stream_filter_add((GMimeStreamFilter *)f_stream, filter);
 
     /* create wrapper object */
+#ifndef GMIME26
     wrapper = g_mime_data_wrapper_new_with_stream(f_stream, GMIME_PART_ENCODING_BASE64);
+#else
+    wrapper = g_mime_data_wrapper_new_with_stream(f_stream, GMIME_CONTENT_ENCODING_BASE64);
+#endif
 
     /* set part */
     g_mime_part_set_content_object(part, wrapper);
+
+#ifndef GMIME26
     g_mime_multipart_add_part((GMimeMultipart *)object, (GMimeObject *)part);
+#else
+    g_mime_multipart_add((GMimeMultipart *)object, (GMimeObject *)part);
+#endif
 
     g_object_unref (filter);
     g_object_unref (part);
     g_object_unref (wrapper);
     g_object_unref (f_stream);
 
-#ifndef GMIME_2_4
+#ifndef GMIME24 
     g_object_unref (object);
 #endif
 
@@ -662,14 +712,22 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     g_object_unref (parser);
 
     /* Add header */
+#ifndef GMIME26
     g_mime_message_add_header(mz->message, XHEADERNAME, XHEADERVALUE);
+#else
+    g_mime_object_append_header((GMimeObject *)mz->message, XHEADERNAME, XHEADERVALUE);
+#endif
 
     /* Get header subject */
     mz->subject = g_mime_message_get_subject(mz->message);
 
     /* Get header date */
     if (cfg->cf_settimezone == 0) {
+#ifndef GMIME26
         mz->date = g_mime_message_get_date_string(mz->message);
+#else
+        mz->date = g_mime_message_get_date_as_string(mz->message);
+#endif
     } else {
         /* Repairing The display of the date 2014/05/08 (Thu) */
         mz->date =  g_mime_utils_header_format_date (mz->message->date,
@@ -680,16 +738,21 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     object = g_mime_message_get_mime_part(mz->message);
 
     if (!GMIME_IS_MULTIPART (object)) {
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	pthread_mutex_unlock(&gmime_lock);
 	return(PM_NO_MULTIPART);
     }
 
     ct_object = g_mime_object_get_content_type(object);
+
     if ((strncmp(ct_object->type, CONTENT_T_MULTIPART, LEN_CONTENT_T_MULTIPART) == 0) && 
         ((strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0) ||
          (strncmp(ct_object->subtype, CONTENT_SUBT_ALTERNATIVE, LEN_CONTENT_SUBT_ALTERNATIVE) == 0))) {
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	pthread_mutex_unlock(&gmime_lock);
 	return(PM_NO_ATTACHFILE);
     }
@@ -700,7 +763,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 
     if (tmpstr == NULL) {
 	log(ERR_MEMORY_ALLOCATE, "parse_mail", "tmpstr", strerror(errno));
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	pthread_mutex_unlock(&gmime_lock);
 	return(PM_FAILED);
     }
@@ -709,7 +774,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     tmpdir = mkdtemp(tmpstr);
     if (tmpdir == NULL) {
         log(ERR_DIRECTORY_MAKE, "parse_mail", tmpstr, strerror(errno));
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	free(tmpstr);
 	pthread_mutex_unlock(&gmime_lock);
 	return(PM_FAILED);
@@ -717,7 +784,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     mz->zipdir = strdup(tmpdir);
     if (mz->zipdir == NULL) {
 	log(ERR_MEMORY_ALLOCATE, "parse_mail", "mz->zipdir", strerror(errno));
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	free(tmpstr);
 	pthread_mutex_unlock(&gmime_lock);
 	return -1;
@@ -725,7 +794,9 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     free(tmpstr);
 
     if ((ret = drop_file(object, cfg, mz)) != 0) {
+#ifndef GMIME24
         g_object_unref (object);
+#endif
 	pthread_mutex_unlock(&gmime_lock);
         if (ret == -2) {
 /* if cannot convert character code then set filename is unknown file */
@@ -737,7 +808,7 @@ printf("errror \n");
 	return -1;
     }
 
-#ifndef GMIME_2_4
+#ifndef GMIME24
     g_object_unref (object);
 #endif
 
@@ -767,8 +838,14 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
     int count = 0;
     FILE *wfp;
 
+
     /* get attach file number */
+#ifndef GMIME26
     index = g_mime_multipart_get_number((GMimeMultipart *)object);
+#else
+    index = g_mime_multipart_get_count((GMimeMultipart *)object);
+#endif
+
 
     for (i = index - 1; i > 0; i--) {
 	att = g_mime_multipart_get_part((GMimeMultipart *)object, i);
@@ -777,17 +854,25 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 	    filename = MESSAGE_FILENAME;
 	} else if (GMIME_IS_MULTIPART (att)) {
 	    ret = drop_file(att, cfg, mz);
+
+#ifndef GMIME24
 	    g_object_unref (att);
+#endif
+
 	    if (ret < 0) {
 		return -1;
 	    } 
 	    continue;
+
 	} else {
 
 	    /* get filename */
 	    filename = g_mime_part_get_filename((GMimePart *)att);
+
 	    if (filename == NULL) {
+#ifndef GMIME24 
 	        g_object_unref (att);
+#endif
 	        continue;
 	    }
 	}
@@ -800,12 +885,15 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 	}
 
 	tmpname = strdup(filename);
+
 	if (tmpname == NULL) {
 	    log(ERR_MEMORY_ALLOCATE, "drop_file", "tmpname", strerror(errno));
+#ifndef GMIME24
 	    g_object_unref (att);
+#endif
 	    return -1;
         }
-	
+
 	/* convert str code */
 	if (dg_str2code(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
             /* START ADD 20150323 */
@@ -813,7 +901,11 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
             tmpfilename = strdup(cfg->cf_attachmentfilealias);
             if (tmpfilename == NULL) {
 	        log(ERR_MEMORY_ALLOCATE, "drop_file", "tmpfilename", strerror(errno));
+
+#ifndef GMIME24
 	        g_object_unref (att);
+#endif
+
 	        return -1;
             }
 
@@ -832,19 +924,27 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
         mk_new_filename(newfilename, tmpfilename, mz->zipdir, count);
 
         if (push_attnamelist(&(mz->namelist), newfilename) != 0) {
+#ifndef GMIME24
             g_object_unref (att);
+#endif
 	    free(tmpfilename);
             return -1;
         }
+
 	free(tmpfilename);
 
 	snprintf(tmppath, PATH_MAX, FILE_PATH, mz->zipdir, newfilename);
 	DEBUGLOG("attach_file_name :%s\n", tmppath);
 
 	wfp = fopen(tmppath, "w");
+
 	if (wfp == NULL) {
 	    log(ERR_FILE_OPEN, "drop_file", tmppath);
+
+#ifndef GMIME24
 	    g_object_unref (att);
+#endif
+
 	    return -1;
 	}
 
@@ -852,30 +952,58 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 
 	if (GMIME_IS_MESSAGE_PART(att)) {
 	    message = g_mime_message_part_get_message((GMimeMessagePart *)att);
-	    ret = g_mime_message_write_to_stream (message, w_stream);
+
+#ifndef GMIME26
+            ret = g_mime_message_write_to_stream (message, w_stream);
+#else
+            ret = g_mime_object_write_to_stream ((GMimeObject *)message, w_stream);
+#endif
+
+#ifndef GMIME24
             g_object_unref (message);
+#endif
             g_object_unref (w_stream);
+
 	} else {
 	    wrapper = g_mime_part_get_content_object((GMimePart *)att);
 	    if (wrapper == NULL) {
 	        log(ERR_GMIME, "drop_file", "g_mime_part_get_content_object");
+
+#ifndef GMIME24
 	        g_object_unref (att);
+#endif
+
                 g_object_unref (w_stream);
 	        return -1;
 	    }
 
 	    ret = g_mime_data_wrapper_write_to_stream(wrapper, w_stream);
+
+#ifndef GMIME24
             g_object_unref (wrapper);
+#endif
             g_object_unref (w_stream);
+
 	}
 	if (ret < 0) {
 	    log(ERR_GMIME, "drop_file", "g_mime_data_wrapper_write_to_stream");
+
+#ifndef GMIME24
 	    g_object_unref (att);
+#endif
+
 	    return -1;
 	}
 
+#ifndef GMIME26
         g_mime_multipart_remove_part((GMimeMultipart *)object, att);
-        g_object_unref (att);
+#else
+        g_mime_multipart_remove((GMimeMultipart *)object, (GMimeObject *)att);
+#endif
+
+#ifndef GMIME24
+	g_object_unref (att);
+#endif
     }
 
     return 0;
@@ -1002,9 +1130,9 @@ int
 check_ascii(char *str)
 {
     int ret;
-    int i, j;
+    int i;
 
-    for (i = 0, j = 0; str[i] != '\0'; i++) {
+    for (i = 0; str[i] != '\0'; i++) {
 
         /* Ascii Check */
         ret = isascii(str[i]);
